@@ -18,6 +18,7 @@
 #include <KFileUtils>
 #include <KPluginMetaData>
 
+#include <KApplicationTrader>
 #include <QDBusConnection>
 #include <QDir>
 #include <QGuiApplication>
@@ -529,6 +530,21 @@ void GlobalShortcutsRegistry::loadSettings()
         actionComp->activateGlobalShortcutContext(QStringLiteral("default"));
         actionComp->loadFromService();
     }
+
+    auto appsWithShortcuts = KApplicationTrader::query([](const KService::Ptr &service) {
+        return !service->property<QString>(QStringLiteral("X-KDE-Shortcuts")).isEmpty();
+    });
+
+    for (auto service : appsWithShortcuts) {
+        auto it = findByName(service->storageId());
+        if (it != m_components.cend()) {
+            continue;
+        }
+
+        auto *actionComp = createServiceActionComponent(service);
+        actionComp->activateGlobalShortcutContext(QStringLiteral("default"));
+        actionComp->loadFromService();
+    }
 }
 
 void GlobalShortcutsRegistry::grabKeys()
